Backend modules — polyfemos 0.3.29 documentation

# Backend modules

`polyfemos.back.filewriter` | Contains classes for writing state of health files
`polyfemos.back.interpreter` | Contains `Interpreter` for reading ‘*conf’ files
`polyfemos.back.main` | Backend of polyfemos
`polyfemos.back.parameter` | Contains `Parameter` class
`polyfemos.back.seismic.edlogreader` | Reads Earth Data LOG files
`polyfemos.back.seismic.lumberjack` | Functions for reading and parsing data from state of health and data files.
`polyfemos.back.seismic.scanner` | Scans available mseed files.
`polyfemos.back.station` | Contains classes for handling station information